@@ -164,13 +164,17 @@
     if (is.numeric(x[[3]])) {
       assign("curLow", as.numeric(x[[3]]), envir=env)
     } else {
-      assign("err", unique(c(env$err, paste0("syntax error '", deparse1(x), "': limits must be numeric"))))
+      assign("err", unique(c(env$err,
+                             paste0("syntax error '", deparse1(x),
+                                    "': limits must be numeric"))))
       assign("curLow", -Inf, envir=env)
     }
     if (is.numeric(x[[4]])) {
       assign("curHi", as.numeric(x[[4]]), envir=env)
     } else {
-      env$err <- unique(c(env$err, paste0("syntax error '", deparse1(x), "': limits must be numeric")))
+      env$err <- unique(c(env$err,
+                          paste0("syntax error '", deparse1(x),
+                                 "': limits must be numeric")))
       assign("curHi", Inf, envir=env)
     }
     x <- x[1:2]
@@ -179,7 +183,10 @@
     if (is.numeric(x[[3]])) {
       assign("curLow", as.numeric(x[[3]]), envir=env)
     } else {
-      assign("err", unique(c(env$err, paste0("syntax error '", deparse1(x), "': limits must be numeric"))),
+      assign("err",
+             unique(c(env$err,
+                      paste0("syntax error '", deparse1(x),
+                             "': limits must be numeric"))),
              envir=env)
       assign("curLow", -Inf, envir=env)
     }
@@ -190,12 +197,30 @@
     assign("curHi", 1, envir=env)
   }
   if (env$curLow >= env$curHi) {
-    assign("err", unique(c(env$err, paste0("syntax error '", deparse1(x), "': limits must be lower, higher"))),
+    assign("err",
+           unique(c(env$err,
+                    paste0("syntax error '", deparse1(x),
+                           "': limits must be lower, higher"))),
            envir=env)
   }
   x
 }
 
+.muRefExtractTheta <- function(x, env) {
+  if (is.name(x)) {
+    .n <- as.character(x)
+    .lhs <- deparse1(env$curLhs)
+    if (any(.n == env$info$theta)) {
+      return(.n)
+    } 
+    return(NULL)
+  } else if (is.call(x)) {
+    return(do.call(`c`, lapply(x[-1], .muRefExtractTheta, env=env)))
+  } else {
+    return(NULL)
+  }
+}
+
 #' Extract single variable names from a expression
 #'
 #' @param x Expression
@@ -235,6 +260,7 @@
 #' @return A list of covariates with estimates attached
 #'
 #' @author Matthew Fidler
+#' 
 #' @noRd
 .muRefExtractMultiplyMuCovariates <- function(x, doubleNames, env) {
   c(doubleNames, do.call(`c`, lapply(x, function(y) {
@@ -246,24 +272,46 @@
           if (any(.y2[1] == env$info$cov) &&
                 any(.y2[2] == env$info$theta)) {
             if (any(.y2[1] == names(doubleNames))) {
-              env$err <- unique(c(env$err, paste0("syntax error: covariate '", .y2[1],
-                                                  "' is duplicated in mu-referenced expression for '",
-                                                  .y2[2], "' and '", doubleNames[[.y2[1]]], "'")))
+              env$err <- unique(c(env$err,
+                                  paste0("syntax error: covariate '", .y2[1],
+                                         "' is duplicated in mu-referenced expression for '",
+                                         .y2[2], "' and '", doubleNames[[.y2[1]]], "'")))
             }
             env$.found <- TRUE
             return(setNames(list(.y2[2]), .y2[1]))
           } else if (any(.y2[2] == env$info$cov) &&
                        any(.y2[1] == env$info$theta)) {
             if (any(.y2[2] == names(doubleNames))) {
-              env$err <- unique(c(env$err, paste0("syntax error: covariate '", .y2[2],
-                                                  "' is duplicated in mu-referenced expression for '",
-                                                  .y2[1], "' and '", doubleNames[[.y2[2]]], "'")))
+              env$err <- unique(c(env$err,
+                                  paste0("syntax error: covariate '", .y2[2],
+                                         "' is duplicated in mu-referenced expression for '",
+                                         .y2[1], "' and '", doubleNames[[.y2[2]]], "'")))
             }
             env$.found <- TRUE
             return(setNames(list(.y2[1]), .y2[2]))
           }
         }
       }
+      .thetas <- try(.muRefExtractTheta(y, env), silent=TRUE)
+      if (inherits(.thetas, "try-error")) .thetas <- NULL
+      if (length(.thetas) == 1L) {
+        .d <- try(symengine::D(get("rxdummyLhs", rxS(paste0("rxdummyLhs=", deparse1(y)))), .thetas),
+                  silent=TRUE)
+        .extra <- try(str2lang(rxFromSE(.d)),
+                      silent=TRUE)
+        .thetaD <- try(.muRefExtractTheta(.extra, env), silent=TRUE)
+        if (inherits(.thetaD, "try-error")) .thetaD <- NULL
+        if (is.null(.thetaD)) {
+          # mu2 expression
+          env$.found <- TRUE
+          env$mu2RefCovariateReplaceDataFrame <-
+            rbind(env$mu2RefCovariateReplaceDataFrame,
+                  data.frame(covariate=deparse1(.extra),
+                             covariateParameter=.thetas,
+                             modelExpression=deparse1(y)))
+          return(setNames(list(.thetas), deparse1(.extra)))
+        }
+      }
       return(NULL)
     }
     return(NULL)
@@ -330,7 +378,9 @@
       # variables, could be an error in coding, perhaps a warning
       # should be issued?
       env$muRefDropParameters <- rbind(env$muRefDropParameters,
-                                       data.frame(parameter=.names[.wt], term=with(env$muRefCovariateDataFrame[.w, ], paste0(covariate, "*", covariateParameter))))
+                                       data.frame(parameter=.names[.wt],
+                                                  term=with(env$muRefCovariateDataFrame[.w, ],
+                                                            paste0(covariate, "*", covariateParameter))))
       env$muRefCovariateDataFrame <- env$muRefCovariateDataFrame[-.w, ]
       .muRefDowngradeEvalToAdditive(.we, .wt, .names, env)
     }
@@ -369,16 +419,19 @@
         .w2 <- .w[which(!(.multPrior %in% .multBoth))]
         if (length(.w2) > 0) {
           # Maybe warn that these are dropped
-          env$muRefDropParameters <- rbind(env$muRefDropParameters,
-                                           data.frame(parameter=.names[.wt],
-                                                      term=with(env$muRefCovariateDataFrame[.w2, ],
-                                                                paste0(covariate, "*", covariateParameter))))
+          env$muRefDropParameters <-
+            rbind(env$muRefDropParameters,
+                  data.frame(parameter=.names[.wt],
+                             term=with(env$muRefCovariateDataFrame[.w2, ],
+                                       paste0(covariate, "*", covariateParameter))))
           env$muRefCovariateDataFrame <- env$muRefCovariateDataFrame[-.w2,, drop = FALSE]
           .muRefDowngradeEvalToAdditive(.we, .wt, .names, env)
         }
       }
     } else {
-      .df <- data.frame(theta=.names[.wt], covariate=.covariate, covariateParameter=.covariateParameter)
+      .df <- data.frame(theta=.names[.wt],
+                        covariate=.covariate,
+                        covariateParameter=.covariateParameter)
       env$muRefCovariateDataFrame <- rbind(env$muRefCovariateDataFrame, .df)
     }
   }
@@ -409,8 +462,10 @@
       # Previously, this was thought to have mu referenced
       # variables, could be an error in coding, perhaps a warning
       # should be issued?
-      .extraDrop <- data.frame(parameter=.names[.wcur], term=env$muRefExtra$extra[.w])
-      env$muRefDropParameters <- rbind(env$muRefDropParameters, .extraDrop)
+      .extraDrop <- data.frame(parameter=.names[.wcur],
+                               term=env$muRefExtra$extra[.w])
+      env$muRefDropParameters <- rbind(env$muRefDropParameters,
+                                       .extraDrop)
       env$muRefExtra <- env$muRefExtra[-.w, ]
       .muRefDowngradeEvalToAdditive(.we, .wt, .names, env)
     }
@@ -419,7 +474,8 @@
     # as not having double names.  Perhaps a warning should be
     # issued for this condition
     env$muRefDropParameters <- rbind(env$muRefDropParameters,
-                                     data.frame(parameter=.names[.wcur], term=.extraItems))
+                                     data.frame(parameter=.names[.wcur],
+                                                term=.extraItems))
     .muRefDowngradeEvalToAdditive(.we, .wt, .names, env)
   } else {
     if (length(.w) > 0) {
@@ -449,7 +505,8 @@
         }
       }
     } else {
-      .df <- data.frame(parameter=.names[.wcur], extra=.extraItems)
+      .df <- data.frame(parameter=.names[.wcur],
+                        extra=.extraItems)
       env$muRefExtra <- rbind(env$muRefExtra, .df)
     }
   }
@@ -487,10 +544,10 @@
     }
   }
 }
-
 # This function handles the extra information in a theta based mu referenced
 
-#' This handles the case where there is a mu referenced single theta with a reference population eta
+#' This handles the case where there is a mu referenced single theta
+#' with a reference population eta
 #'
 #' @param .we this represents the item number in `.names` that is the
 #'   mu-referenced population eta
@@ -547,7 +604,11 @@
           .muRefSetNonMuEta(.curEta, env)
         }
       } else {
-        env$muRefDataFrame <- rbind(env$muRefDataFrame, data.frame(theta=.names[.wt], eta=.names[.we], level="id"))
+        env$muRefDataFrame <-
+          rbind(env$muRefDataFrame,
+                data.frame(theta=.names[.wt],
+                           eta=.names[.we],
+                           level="id"))
       }
     }
   } else if (length(.we) != 0) {
@@ -607,7 +668,8 @@
   if (length(.wt) >= 2) {
     env$err <- unique(c(env$err,
                         paste0("syntax error: 2+ single population parameters in a single mu-referenced expression: '",
-                               paste(env$info$theta[.wt], collapse="', '"), "'\nthis could occur when a between subject variability parameter is not initialized with a '~'")))
+                               paste(env$info$theta[.wt], collapse="', '"),
+                               "'\nthis could occur when a between subject variability parameter is not initialized with a '~'")))
   } else if (length(.wt) == 1) {
     if (!is.null(.extraItems)) {
       .ord <- order(vapply(.extraItems, nchar, integer(1)))
@@ -732,7 +794,9 @@
   .blankEval <- ""
   if (inherits(set, "character")) {
     if (length(.w) == 0L) {
-      env$muRefCurEval <- rbind(env$muRefCurEval, data.frame(parameter=parameter, curEval=set, low=env$curLow, hi=env$curHi))
+      env$muRefCurEval <-
+        rbind(env$muRefCurEval,
+              data.frame(parameter=parameter, curEval=set, low=env$curLow, hi=env$curHi))
     } else {
       env$muRefCurEval$curEval[.w] <- set
     }
@@ -744,7 +808,9 @@
       if (is.null(env$curHi)) {
         env$curHi <- NA_real_
       }
-      env$muRefCurEval <- rbind(env$muRefCurEval, data.frame(parameter=parameter, curEval=.curEval, low=env$curLow, hi=env$curHi))
+      env$muRefCurEval <-
+        rbind(env$muRefCurEval,
+              data.frame(parameter=parameter, curEval=.curEval, low=env$curLow, hi=env$curHi))
     } else if (env$muRefCurEval$curEval[.w] != env$.curEval) {
       env$muRefCurEval$curEval[.w] <- .blankEval
     }
@@ -826,6 +892,7 @@
   .env$muRefExtra <- data.frame(parameter=character(0), extra=character(0))
   .env$muRefExtraEmpty <- NULL
   .env$muRefCovariateDataFrame <- data.frame(theta=character(0), covariate=character(0), covariateParameter=character(0))
+  .env$mu2RefCovariateReplaceDataFrame <- data.frame(covariate=character(0), covariateParameter=character(0), modelExpression=character(0))
   .env$muRefDropParameters <- data.frame(parameter=character(0), term=character(0))
   .env$muRefCovariateEmpty <- NULL
   .env$nonMuEtas <- NULL
@@ -859,21 +926,27 @@
       .upper <- .iniDf$upper[.err]
       if (.range[1] > .est) {
         env$err <- c(env$err,
-                     paste0("'", .name, "' estimate (", .est, ") needs to be above ", .range[1]))
+                     paste0("'", .name, "' estimate (",
+                            .est, ") needs to be above ", .range[1]))
       }
       if (.range[2] < .est) {
         env$err <- c(env$err,
-                     paste0("'", .name, "' estimate (", .est, ") needs to be below ", .range[2]))
+                     paste0("'", .name, "' estimate (",
+                            .est, ") needs to be below ", .range[2]))
       }
       if (.lower < .range[1]) {
         if (rxode2.verbose.pipe && is.finite(.lower)) {
-          .minfo(paste0("'", .name, "' lower bound (", .lower, ") needs to be equal or above ", .range[1], "; adjusting"))
+          .minfo(paste0("'", .name, "' lower bound (",
+                        .lower, ") needs to be equal or above ", .range[1],
+                        "; adjusting"))
         }
         .lower <- .range[1]
       }
       if (.upper > .range[2]) {
         if (rxode2.verbose.pipe && is.finite(.upper)) {
-          .minfo(paste0("'", .name, "' upper bound (", .upper, ") needs to be equal or below ", .range[2],"; adjusting"))
+          .minfo(paste0("'", .name, "' upper bound (", .upper,
+                        ") needs to be equal or below ", .range[2],
+                        "; adjusting"))
         }
         .upper <- .range[2]
       }
@@ -899,12 +972,15 @@
   } else {
     .errEsts <- .iniDf[.iniDf$condition %in% ui$predDf$cond, "name"]
   }
-  .estName <- .iniDf$name[!is.na(.iniDf$ntheta) | (!is.na(.iniDf$neta1) & .iniDf$neta1 == .iniDf$neta2)]
+  .estName <- .iniDf$name[!is.na(.iniDf$ntheta) |
+                            (!is.na(.iniDf$neta1) & .iniDf$neta1 == .iniDf$neta2)]
   .estName <- c(.estName, .errEsts)
   .missingPars <- setdiff(.estName, c(.mv$params, .errEsts))
   if (length(.missingPars) > 0) {
-    ui$err <- c(ui$err, paste0("the following parameter(s) were in the ini block but not in the model block: ",
-                               paste(.missingPars, collapse=", ")))
+    ui$err <-
+      c(ui$err,
+        paste0("the following parameter(s) were in the ini block but not in the model block: ",
+               paste(.missingPars, collapse=", ")))
   }
   invisible()
 }
@@ -919,7 +995,9 @@
   .iniDf <- ui$iniDf
   .bad <- .iniDf$name[is.infinite(.iniDf$est) | is.na(.iniDf$est)]
   if (length(.bad) > 0) {
-    ui$err <- c(ui$err, paste0("infinite/NA initial parameters: ", paste(.bad, collapse=", ")))
+    ui$err <-
+      c(ui$err,
+        paste0("infinite/NA initial parameters: ", paste(.bad, collapse=", ")))
   }
   invisible()
 }
@@ -952,6 +1030,30 @@
   })
 }
 
+
+.muRefSeparateCalculatedMuRefCovs <- function(.env) {
+  if (length(.env$mu2RefCovariateReplaceDataFrame$covariate) == 0L) {
+    .env$mu2RefCovariateReplaceDataFrame$theta <- character(0)
+  } else {
+    .env$mu2RefCovariateReplaceDataFrame$theta <- NA_character_
+    lapply(seq_along(.env$mu2RefCovariateReplaceDataFrame$covariate),
+           function(i) {
+             .cov <- .env$mu2RefCovariateReplaceDataFrame$covariate[i]
+             .covPar <- .env$mu2RefCovariateReplaceDataFrame$covariateParameter[i]
+             .wmu <- which(.env$muRefCovariateDataFrame$covariate == .cov &
+                             .env$mu2RefCovariateReplaceDataFrame$covariateParameter[i] == .covPar)
+             if (length(.wmu) == 1L) {
+               .theta <- .env$muRefCovariateDataFrame$theta[.wmu]
+               .env$muRefCovariateDataFrame <- .env$muRefCovariateDataFrame[-.wmu,]
+               .env$mu2RefCovariateReplaceDataFrame$theta[i] <- .theta
+             }
+           })
+  }
+  .env$mu2RefCovariateReplaceDataFrame <- .env$mu2RefCovariateReplaceDataFrame[,c("theta", "covariate", "covariateParameter", "modelExpression")]
+  row.names(.env$muRefCovariateDataFrame) <- NULL
+  row.names(.env$mu2RefCovariateReplaceDataFrame) <- NULL
+}
+
 #' Get mu-referencing model from model variables
 #'
 #' The rxMuRef is the core of the nlmixr ui functions
@@ -970,29 +1072,29 @@
 #' # First lets get a lotri initialization block:
 #'
 #' ini <- lotri({
-#'    ## You may label each parameter with a comment
-#'    tka <- 0.45 # Log Ka
-#'    tcl <- log(c(0, 2.7, 100)) # Log Cl
-#'    ## This works with interactive models
-#'    ## You may also label the preceding line with label("label text")
-#'    tv <- 3.45; label("log V")
-#'    ## the label("Label name") works with all models
-#'    eta.ka ~ 0.6
-#'    eta.cl + eta.v ~ c(0.3,
-#'                       0.001, 0.1)
-#'    add.sd <- 0.7
+#'   ## You may label each parameter with a comment
+#'   tka <- 0.45 # Log Ka
+#'   tcl <- log(c(0, 2.7, 100)) # Log Cl
+#'   ## This works with interactive models
+#'   ## You may also label the preceding line with label("label text")
+#'   tv <- 3.45; label("log V")
+#'   ## the label("Label name") works with all models
+#'   eta.ka ~ 0.6
+#'   eta.cl + eta.v ~ c(0.3,
+#'                      0.001, 0.1)
+#'   add.sd <- 0.7
 #' })
 #'
 #'
 #' ini2 <- lotri({
-#'        ## You may label each parameter with a comment
-#'        tka <- 0.45 # Log Ka
-#'        tcl <- log(c(0, 2.7, 100)) # Log Cl
-#'        ## This works with interactive models
-#'        ## You may also label the preceding line with label("label text")
-#'        tv <- 3.45; label("log V")
-#'        add.sd <- 0.7
-#'     })
+#'   ## You may label each parameter with a comment
+#'   tka <- 0.45 # Log Ka
+#'   tcl <- log(c(0, 2.7, 100)) # Log Cl
+#'   ## This works with interactive models
+#'   ## You may also label the preceding line with label("label text")
+#'   tv <- 3.45; label("log V")
+#'   add.sd <- 0.7
+#' })
 #'
 #' @noRd
 .rxMuRef <- function(mod, ini=NULL) {
@@ -1003,6 +1105,7 @@
   .checkForInfiniteOrNaParameters(.env)
   .checkForAtLeastOneEstimatedOrModeledParameterPerEndpoint(.env)
   .muRefDowngrade(.env)
+  .muRefSeparateCalculatedMuRefCovs(.env)
   if (.env$hasErrors) {
     .errMsg <- paste0(crayon::bold$blue("\nmodel"), "({}) errors:\n",
                       paste(vapply(seq_along(.env$lstExpr),
