@@ -83,6 +83,8 @@ NA_LOGICAL <- NA # nolint
 #'   print on every step (except ME/indLin), otherwise when `FALSE`
 #'   print only when calculating the `d/dt`
 #'
+#' @inheritParams rxode2parse::rxode2parse
+#'
 #' @details
 #'
 #' The `Rx` in the name `rxode2` is meant to suggest the
@@ -91,20 +93,9 @@ NA_LOGICAL <- NA # nolint
 #' pharmacokinetics (PK), pharmacodynamics (PD), disease progression,
 #' drug-disease modeling, etc.
 #'
-#' The ODE-based model specification may be coded inside a character
-#' string or in a text file, see Section *rxode2 Syntax* below for
-#' coding details.  An internal `rxode2` compilation manager
-#' object translates the ODE system into C, compiles it, and
-#' dynamically loads the object code into the current R session.  The
-#' call to `rxode2` produces an object of class `rxode2` which
-#' consists of a list-like structure (environment) with various member
-#' functions (see Section *Value* below).
+#' @section Creating rxode2 models
 #'
-#' For evaluating `rxode2` models, two types of inputs may be
-#' provided: a required set of time points for querying the state of
-#' the ODE system and an optional set of doses (input amounts).  These
-#' inputs are combined into a single *event table* object created
-#' with the function [eventTable()] or [et()].
+#' @includeRmd man/rmdhunks/rxode2-create-models.Rmd
 #'
 #' @includeRmd man/rmdhunks/rxode2-syntax-hunk.Rmd
 #'
@@ -153,7 +144,7 @@ NA_LOGICAL <- NA # nolint
 #'
 #'           `atol`: a numeric absolute tolerance (1e-08 by default);
 #'
-#'           `rtol`: a numeric relative tolerance (1e-06 by default).e
+#'           `rtol`: a numeric relative tolerance (1e-06 by default).
 #'
 #'           The output of \dQuote{solve} is a matrix with as many rows as there
 #'           are sampled time points and as many columns as system variables
@@ -207,20 +198,32 @@ NA_LOGICAL <- NA # nolint
 #'
 #' @examples
 #' \donttest{
-#' # Step 1 - Create a model specification
-#' ode <- "
-#'    # A 4-compartment model, 3 PK and a PD (effect) compartment
-#'    # (notice state variable names 'depot', 'centr', 'peri', 'eff')
 #'
-#'    C2 = centr/V2;
-#'    C3 = peri/V3;
-#'    d/dt(depot) =-KA*depot;
-#'    d/dt(centr) = KA*depot - CL*C2 - Q*C2 + Q*C3;
-#'    d/dt(peri)  =                    Q*C2 - Q*C3;
-#'    d/dt(eff)  = Kin - Kout*(1-C2/(EC50+C2))*eff;
-#' "
+#' mod <- function() {
+#'   ini({
+#'     KA   <- .291
+#'     CL   <- 18.6
+#'     V2   <- 40.2
+#'     Q    <- 10.5
+#'     V3   <- 297.0
+#'     Kin  <- 1.0
+#'     Kout <- 1.0
+#'     EC50 <- 200.0
+#'   })
+#'   model({
+#'     # A 4-compartment model, 3 PK and a PD (effect) compartment
+#'     # (notice state variable names 'depot', 'centr', 'peri', 'eff')
+#'     C2 <- centr/V2
+#'     C3 <- peri/V3
+#'     d/dt(depot) <- -KA*depot;
+#'     d/dt(centr) <- KA*depot - CL*C2 - Q*C2 + Q*C3;
+#'     d/dt(peri)  <-                    Q*C2 - Q*C3;
+#'     d/dt(eff)   <- Kin - Kout*(1-C2/(EC50+C2))*eff;
+#'     eff(0)      <- 1
+#'   })
+#' }
 #'
-#' m1 <- rxode(model = ode)
+#' m1 <- rxode2(mod)
 #' print(m1)
 #'
 #' # Step 2 - Create the model input as an EventTable,
@@ -228,76 +231,20 @@ NA_LOGICAL <- NA # nolint
 #'
 #' # QD (once daily) dosing for 5 days.
 #'
-#' qd <- eventTable(amount.units = "ug", time.units = "hours")
-#' qd$add.dosing(dose = 10000, nbr.doses = 5, dosing.interval = 24)
+#' qd <- et(amountUnits = "ug", timeUnits = "hours") %>%
+#'   et(amt = 10000, addl = 4, ii = 24)
 #'
 #' # Sample the system hourly during the first day, every 8 hours
 #' # then after
+#' qd <- qd %>% et(0:24) %>%
+#'   et(from = 24 + 8, to = 5 * 24, by = 8)
 #'
-#' qd$add.sampling(0:24)
-#' qd$add.sampling(seq(from = 24 + 8, to = 5 * 24, by = 8))
+#' # Step 3 - solve the system
 #'
-#' # Step 3 - set starting parameter estimates and initial
-#' # values of the state
-#'
-#' theta <-
-#'   c(
-#'     KA = .291, CL = 18.6,
-#'     V2 = 40.2, Q = 10.5, V3 = 297.0,
-#'     Kin = 1.0, Kout = 1.0, EC50 = 200.0
-#'   )
-#'
-#' # init state variable
-#' inits <- c(0, 0, 0, 1)
-#' # Step 4 - Fit the model to the data
-#'
-#' qd.cp <- m1$solve(theta, events = qd, inits)
+#' qd.cp <- rxSolve(m1, qd)
 #'
 #' head(qd.cp)
 #'
-#' # This returns a matrix.  Note that you can also
-#' # solve using name initial values. For example:
-#'
-#' inits <- c(eff = 1)
-#' qd.cp <- solve(m1, theta, events = qd, inits)
-#' print(qd.cp)
-#'
-#' plot(qd.cp)
-#'
-#' # You can also directly simulate from a nlmixr model
-#'  f <- function() {
-#'    ini({
-#'      KA <- .291
-#'      CL <- 18.6
-#'      V2 <- 40.2
-#'      Q <- 10.5
-#'      V3 <- 297.0
-#'      Kin <- 1.0
-#'      Kout <- 1.0
-#'      EC50 <- 200.0
-#'    })
-#'    model({
-#'      # A 4-compartment model, 3 PK and a PD (effect) compartment
-#'      # (notice state variable names 'depot', 'centr', 'peri', 'eff')
-#'      C2 <- centr/V2
-#'      C3 <- peri/V3
-#'      d/dt(depot) <- -KA*depot
-#'      d/dt(centr) <- KA*depot - CL*C2 - Q*C2 + Q*C3
-#'      d/dt(peri)  <-                    Q*C2 - Q*C3
-#'      d/dt(eff)   <- Kin - Kout*(1-C2/(EC50+C2))*eff
-#'      eff(0) <- 1
-#'    })
-#'  }
-#'
-#'  u <- f()
-#'
-#'  # this pre-compiles and displays the simulation model
-#'  u$simulationModel
-#'
-#'  qd.cp <-solve(u, qd)
-#'
-#'  print(qd.cp)
-#'
 #' }
 #'
 #' @keywords models nonlinear
@@ -328,7 +275,9 @@ rxode2 <- # nolint
            linCmtSens = c("linCmtA", "linCmtB", "linCmtC"),
            indLin = FALSE,
            verbose = FALSE,
-           fullPrint=getOption("rxode2.fullPrint", FALSE)) {
+           fullPrint=getOption("rxode2.fullPrint", FALSE),
+           envir=parent.frame()) {
+    rxode2parse::.udfEnvSet(envir)
     assignInMyNamespace(".rxFullPrint", fullPrint)
     rxSuppressMsg()
     rxode2parse::rxParseSuppressMsg()
@@ -466,7 +415,7 @@ rxode2 <- # nolint
           .rx$.clearME()
         })
         .rx$.rxWithWd(wd, {
-          .rx$.extraC(extraC)
+          rxode2parse::.extraC(extraC)
           if (missing.modName) {
             .rxDll <- .rx$rxCompile(.mv,
                                     debug = debug,
@@ -487,7 +436,7 @@ rxode2 <- # nolint
         })
       })
     }))
-    .extraC(extraC)
+    rxode2parse::.extraC(extraC)
     .env$compile()
     .env$get.modelVars <- eval(bquote(function() {
       with(.(.env), {
@@ -525,13 +474,11 @@ rxode2 <- # nolint
     ## cmpMgr = cmpMgr,
     .env$dynLoad <- eval(bquote(function(force = FALSE) {
       rx <- .(.env)
-      class(rx) <- "rxode2"
       rxode2::rxDynLoad(rx)
     }))
     .env$load <- .env$dynLoad
     .env$dynUnload <- eval(bquote(function() {
       rx <- .(.env)
-      class(rx) <- "rxode2"
       rxode2::rxDynUnload(rx)
     }))
     .env$unload <- .env$dynUnload
@@ -558,7 +505,6 @@ rxode2 <- # nolint
             return(TRUE)
           } else {
             rx <- .(.env)
-            class(rx) <- "rxode2"
             rxode2::rxIsLoaded(rx)
           }
         }))
@@ -569,7 +515,6 @@ rxode2 <- # nolint
             stop("cannot delete Dll in package", call. = FALSE)
           } else {
             rx <- .(.env)
-            class(rx) <- "rxode2"
             rxode2::rxDelete(rx)
           }
         }))
@@ -581,12 +526,10 @@ rxode2 <- # nolint
       }))
       .env$isLoaded <- eval(bquote(function() {
         rx <- .(.env)
-        class(rx) <- "rxode2"
         rxode2::rxIsLoaded(rx)
       }))
       .env$delete <- eval(bquote(function() {
         rx <- .(.env)
-        class(rx) <- "rxode2"
         rxode2::rxDelete(rx)
       }))
     }
@@ -694,23 +637,28 @@ rxGetModel <- function(model, calcSens = NULL, calcJac = NULL, collapseModel = N
       model <- model[-length(model)]
     }
     model <- paste(model, collapse = "\n")
-  } else if (is(model, "function") || is(model, "call")) {
+  } else if (inherits(model, "function") || inherits(model, "call")) {
     model <- deparse(body(model))
     if (model[1] == "{") {
       model <- model[-1]
       model <- model[-length(model)]
     }
     model <- paste(model, collapse = "\n")
-  } else if (is(model, "name")) {
+  } else if (inherits(model, "name")) {
     model <- eval(model)
-  } else if (is(model, "character") || is(model, "rxModelText")) {
+  } else if (inherits(model, "character") || inherits(model, "rxModelText")) {
     model <- as.vector(model)
-  } else if (is(model, "rxode2")) {
+  } else if (inherits(model, "rxode2")) {
     model <- rxModelVars(model)
     ## class(model) <- NULL;
-  } else if (is(model, "rxModelVars")) {
+  } else if (inherits(model, "rxModelVars")) {
+  } else if (inherits(model, "rxDll")) {
+    model <- model$args$model
   } else {
-    stop("cannot figure out how to handle the model argument", call. = FALSE)
+    model <- rxModelVars(model)
+    if (!inherits(model, "rxModelVars")) {
+      stop("cannot figure out how to handle the model argument", call. = FALSE)
+    }
   }
   .ret <- rxModelVars(model)
   if (!is.null(calcSens)) {
@@ -1100,7 +1048,7 @@ rxMd5 <- function(model, # Model File
       rxode2.calculate.sensitivity)
     .ret <- c(
       .ret, .tmp, .rxIndLinStrategy, .rxIndLinState,
-      .linCmtSens, ls(.symengineFs), .rxFullPrint
+      .linCmtSens, rxode2parse::.udfMd5Info(), .rxFullPrint
     )
     if (is.null(.md5Rx)) {
       .tmp <- getLoadedDLLs()$rxode2
@@ -1296,13 +1244,13 @@ rxDllLoaded <- rxIsLoaded
 #'
 #' @return An rxDll object that has the following components
 #'
-#' * `dll`{DLL path}
-#' * `model`{model specification}
-#' * `.c`{A function to call C code in the correct context from the DLL
-#'          using the [.C()] function.}
-#' * `.call`{A function to call C code in the correct context from the DLL
-#'          using the [.Call()] function.}
-#' * `args`{A list of the arguments used to create the rxDll object.}
+#' * `dll` DLL path
+#' * `model` model specification
+#' * `.c` A function to call C code in the correct context from the DLL
+#'          using the [.C()] function.
+#' * `.call` A function to call C code in the correct context from the DLL
+#'          using the [.Call()] function.
+#' * `args` A list of the arguments used to create the rxDll object.
 #' @inheritParams rxode2
 #' @seealso [rxode2()]
 #' @author Matthew L.Fidler
@@ -1336,6 +1284,7 @@ rxCompile <- function(model, dir, prefix, force = FALSE, modName = NULL,
       .cc <- gsub("\n", "", .cc)
       .cflags <- rawToChar(sys::exec_internal(file.path(R.home("bin"), "R"), c("CMD", "config", "CFLAGS"))$stdout)
       .cflags <- gsub("\n", "", .cflags)
+      .cflags <- paste0(.cflags, " -O", getOption("rxode2.compile.O", "2"))
       .shlibCflags <- rawToChar(sys::exec_internal(file.path(R.home("bin"), "R"), c("CMD", "config", "SHLIB_CFLAGS"))$stdout)
       .shlibCflags <- gsub("\n", "", .shlibCflags)
       .cpicflags <- rawToChar(sys::exec_internal(file.path(R.home("bin"), "R"), c("CMD", "config", "CPICFLAGS"))$stdout)
@@ -1522,7 +1471,7 @@ rxCompile.rxModelVars <- function(model, # Model
         cat(.ret)
         sink()
         sink(.normalizePath(file.path(.dir, "extraC.h")))
-        cat(.extraCnow)
+        cat(rxode2parse::.extraCnow())
         sink()
         try(dyn.unload(.cDllFile), silent = TRUE)
         try(unlink(.cDllFile))
@@ -1827,17 +1776,17 @@ rxModels_ <- # nolint
 #'
 #' @return A list of rxode2 model properties including:
 #'
-#' * `params`{ a character vector of names of the model parameters}
-#' * `lhs`{ a character vector of the names of the model calculated parameters}
-#' * `state`{ a character vector of the compartments in rxode2 object}
-#' * `trans`{ a named vector of translated model properties
+#' * `params`  a character vector of names of the model parameters
+#' * `lhs` a character vector of the names of the model calculated parameters
+#' * `state` a character vector of the compartments in rxode2 object
+#' * `trans` a named vector of translated model properties
 #'       including what type of jacobian is specified, the `C` function prefixes,
-#'       as well as the `C` functions names to be called through the compiled model.}
-#' * `md5`{a named vector that gives the digest of the model (`file_md5`) and the parsed model
-#'      (`parsed_md5`)}
-#' * `model`{ a named vector giving the input model (`model`),
+#'       as well as the `C` functions names to be called through the compiled model.
+#' * `md5` a named vector that gives the digest of the model (`file_md5`) and the parsed model
+#'      (`parsed_md5`)
+#' * `model`  a named vector giving the input model (`model`),
 #'    normalized model (no comments and standard syntax for parsing, `normModel`),
-#'    and interim code that is used to generate the final C file `parseModel`}
+#'    and interim code that is used to generate the final C file `parseModel`
 #'
 #' @keywords internal
 #' @family Query model information
