@@ -1,4 +1,7 @@
 // -*- mode: c++; c-basic-offset: 2; tab-width: 2; indent-tabs-mode: nil; -*-
+#ifndef R_NO_REMAP
+#define R_NO_REMAP
+#endif
 #define USE_FC_LEN_T
 // [[Rcpp::interfaces(r,cpp)]]
 // [[Rcpp::depends(RcppArmadillo)]]
@@ -360,7 +363,7 @@ extern "C" SEXP rxode2_df(int doDose0, int doTBS) {
           if ((doDose && evid!= 9) || (evid0 == 0 && isObs(evid)) || (evid0 == 1 && evid==0)){
             // Only increment if this is an observation or of this a
             // simulation that requests dosing information too.
-            kk++;
+            kk=min2(kk+1, errNrow-1);
           }
         }
         if (nlhs){
