@@ -1,5 +1,8 @@
 #ifndef __SEED_H__
 #define __SEED_H__
+#ifndef R_NO_REMAP
+#define R_NO_REMAP
+#endif
 
 #if defined(__cplusplus)
 extern "C" {
